//
//  AASFileFilter.h
//  AASFilesystemTools
//
//  Created by Andreas Schwarz on 3/11/08.
//  OS X 10.5 or later required.
/* Copyright (c) 2001-2009, Andreas Schwarz
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
 Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 Neither the names of the Andreas Schwarz or immaterial nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



/* Objects of this class are used to determine whether or not an AASFile (or subclass) object should be included or excluded from a set. This class merely returns 'YES' every time, which would include all file objects in the set. Subclasses can override the filter method to exclude files however they please. For example, if you are using an AASFileLoader to recursively load AASBasicInfoFile objects for a given directory tree, you can pass the AASFileLoader object an instance of the AASFileFilter subclass AASVisibleFileFilter which returns NO if a file is invisible, to keep invisible files out of the returned array. */

#import <Cocoa/Cocoa.h>


@interface AASFileFilter : NSObject {

}

/* Convenience constructor method (autoreleased). */
+ (id)filter;

/* Subclasses should override this method however they see fit to include or exclude the file based on certain criteria. The default implementation returns YES for all objects. */
- (BOOL)shouldIncludeFile:(AASFile *)file;

@end
